# CHANGELOG


## v0.0.6 (August 24, 2020)

- Add colored serializers.
- Add rest framework exception handler.


---


## v0.0.5 (August 24, 2020)

- Fix secret key saving into config file.
- Rename project to `tea-django`.


---


## v0.0.4 (August 23, 2020)

- Fixes.


---


## v0.0.3 (August 23, 2020)
- Move stuff to `tea-console` and `tea` projects. 


---


## v0.0.1 (August 17, 2020)

- Initial beta release. 
